==> gorilla-notes-0.1.0-20200722.222548-1.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$utils.js <==
shadow$provide.module$node_modules$react_player$lib$utils=function(global,require,module,exports){function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj}}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _createForOfIteratorHelper(o){if("undefined"===
typeof Symbol||null==o[Symbol.iterator]){if(Array.isArray(o)||(o=_unsupportedIterableToArray(o))){var i=0,F=function(){};return{s:F,n:function(){return i>=o.length?{done:!0}:{done:!1,value:o[i++]}},e:function(_e2){throw _e2;},f:F}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");}var it,normalCompletion=!0,didErr=!1,err;return{s:function(){it=o[Symbol.iterator]()},n:function(){var step=it.next();
normalCompletion=step.done;return step},e:function(_e3){didErr=!0;err=_e3},f:function(){try{if(!normalCompletion&&null!=it["return"])it["return"]()}finally{if(didErr)throw err;}}}}function _unsupportedIterableToArray(o,minLen){if(o){if("string"===typeof o)return _arrayLikeToArray(o,minLen);var n=Object.prototype.toString.call(o).slice(8,-1);"Object"===n&&o.constructor&&(n=o.constructor.name);if("Map"===n||"Set"===n)return Array.from(n);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return _arrayLikeToArray(o,
minLen)}}function _arrayLikeToArray(arr,len){if(null==len||len>arr.length)len=arr.length;for(var i=0,arr2=Array(len);i<len;i++)arr2[i]=arr[i];return arr2}function parseTimeParam(url,pattern){if(url=url.match(pattern)){url=url[1];if(url.match(MATCH_START_STAMP)){pattern=0;for(var array=MATCH_START_STAMP.exec(url);null!==array;){var _array2=array;_array2=Array.isArray(_array2)?_array2:void 0;if(!_array2)if(_array2=void 0,"undefined"!==typeof Symbol&&Symbol.iterator in Object(array)){var _arr=[],_n=
!0,_d=!1,_e=void 0;try{for(var _i=array[Symbol.iterator]();!(_n=(_array2=_i.next()).done)&&(_arr.push(_array2.value),3!==_arr.length);_n=!0);}catch(err){_d=!0,_e=err}finally{try{if(!_n&&null!=_i["return"])_i["return"]()}finally{if(_d)throw _e;}}_array2=_arr}else _array2=void 0;if(!(array=_array2||_unsupportedIterableToArray(array,3)))throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");_array2=
array;array=_array2[1];_array2=_array2[2];"h"===_array2&&(pattern+=3600*parseInt(array,10));"m"===_array2&&(pattern+=60*parseInt(array,10));"s"===_array2&&(pattern+=parseInt(array,10));array=MATCH_START_STAMP.exec(url)}return pattern}if(MATCH_NUMERIC.test(url))return parseInt(url)}}function isObject(val){return null!==val&&"object"===_typeof(val)}function isEqual(a,b){if("function"===typeof a&&"function"===typeof b||(0,_react.isValidElement)(a)&&(0,_react.isValidElement)(b))return!0;if(a instanceof
Array&&b instanceof Array){if(a.length!==b.length)return!1;for(var i=0;i!==a.length;i++)if(!isEqual(a[i],b[i]))return!1;return!0}if(isObject(a)&&isObject(b)){if(Object.keys(a).length!==Object.keys(b).length)return!1;i=0;for(var _Object$keys=Object.keys(a);i<_Object$keys.length;i++){var key=_Object$keys[i];if(!isEqual(a[key],b[key]))return!1}return!0}return a===b}Object.defineProperty(exports,"__esModule",{value:!0});exports.parseStartTime=function(url){return parseTimeParam(url,MATCH_START_QUERY)};
exports.parseEndTime=function(url){return parseTimeParam(url,MATCH_END_QUERY)};exports.randomString=function(){return Math.random().toString(36).substr(2,5)};exports.queryString=function(object){return Object.keys(object).map(function(key){return"".concat(key,"\x3d").concat(object[key])}).join("\x26")};exports.getSDK=function(url,sdkGlobal){var sdkReady=2<arguments.length&&void 0!==arguments[2]?arguments[2]:null,isLoaded=3<arguments.length&&void 0!==arguments[3]?arguments[3]:function(){return!0},
fetchScript=4<arguments.length&&void 0!==arguments[4]?arguments[4]:_loadScript["default"];return window[sdkGlobal]&&isLoaded(window[sdkGlobal])?Promise.resolve(window[sdkGlobal]):new Promise(function(resolve,reject){if(requests[url])requests[url].push({resolve:resolve,reject:reject});else{requests[url]=[{resolve:resolve,reject:reject}];var onLoaded=function(sdk){requests[url].forEach(function(request){return request.resolve(sdk)})};if(sdkReady){var previousOnReady=window[sdkReady];window[sdkReady]=
function(){previousOnReady&&previousOnReady();onLoaded(window[sdkGlobal])}}fetchScript(url,function(err){err?(requests[url].forEach(function(request){return request.reject(err)}),requests[url]=null):sdkReady||onLoaded(window[sdkGlobal])})}})};exports.getConfig=function(props,defaultProps,showWarning){defaultProps=(0,_deepmerge["default"])(defaultProps.config,props.config);var _iterator=_createForOfIteratorHelper(_props.DEPRECATED_CONFIG_PROPS),_step;try{for(_iterator.s();!(_step=_iterator.n()).done;){var p=
_step.value;if(props[p]){var key=p.replace(/Config$/,""),JSCompiler_temp_const=(0,_deepmerge["default"]),JSCompiler_temp_const$jscomp$0=defaultProps,obj={},key$jscomp$0=key,value=props[p];key$jscomp$0 in obj?Object.defineProperty(obj,key$jscomp$0,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key$jscomp$0]=value;defaultProps=JSCompiler_temp_const(JSCompiler_temp_const$jscomp$0,obj);if(showWarning){var message="ReactPlayer: %c".concat(p," %cis deprecated, please use the config prop instead – ").concat("https://github.com/CookPete/react-player#config-prop");
console.warn(message,"font-weight: bold","")}}}}catch(err){_iterator.e(err)}finally{_iterator.f()}return defaultProps};exports.omit=function(object){for(var _ref,_len=arguments.length,arrays=Array(1<_len?_len-1:0),_key=1;_key<_len;_key++)arrays[_key-1]=arguments[_key];_len=(_ref=[]).concat.apply(_ref,arrays);_ref={};arrays=0;for(_key=Object.keys(object);arrays<_key.length;arrays++){var key=_key[arrays];-1===_len.indexOf(key)&&(_ref[key]=object[key])}return _ref};exports.callPlayer=function(method){if(!this.player||
!this.player[method]){var _this$player="ReactPlayer: ".concat(this.constructor.displayName," player could not call %c").concat(method,"%c – ");this.player?this.player[method]||(_this$player+="The method was not available"):_this$player+="The player was not available";console.warn(_this$player,"font-weight: bold","");return null}for(var _len2=arguments.length,args=Array(1<_len2?_len2-1:0),_key2=1;_key2<_len2;_key2++)args[_key2-1]=arguments[_key2];return(_this$player=this.player)[method].apply(_this$player,
args)};exports.isObject=isObject;exports.isEqual=isEqual;exports.isMediaStream=function(url){return"undefined"!==typeof window&&"undefined"!==typeof window.MediaStream&&url instanceof window.MediaStream};var _react=require("module$node_modules$react$index"),_loadScript=_interopRequireDefault(require("module$node_modules$load_script$index")),_deepmerge=_interopRequireDefault(require("module$node_modules$deepmerge$dist$cjs")),_props=require("module$node_modules$react_player$lib$props"),MATCH_START_QUERY=
/[?&#](?:start|t)=([0-9hms]+)/,MATCH_END_QUERY=/[?&#]end=([0-9hms]+)/,MATCH_START_STAMP=/(\d+)(h|m|s)/g,MATCH_NUMERIC=/^\d+$/,requests={}}
//# sourceMappingURL=module$node_modules$react_player$lib$utils.js.map

==> gorilla-notes-0.3.0-20200822.233548-11.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$utils.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_player$lib$utils=function(global,require,module,exports){function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj}}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _createForOfIteratorHelper(o){if("undefined"===
typeof Symbol||null==o[Symbol.iterator]){if(Array.isArray(o)||(o=_unsupportedIterableToArray(o))){var i=0,F=function(){};return{s:F,n:function(){return i>=o.length?{done:!0}:{done:!1,value:o[i++]}},e:function(_e2){throw _e2;},f:F}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");}var it,normalCompletion=!0,didErr=!1,err;return{s:function(){it=o[Symbol.iterator]()},n:function(){var step=it.next();
normalCompletion=step.done;return step},e:function(_e3){didErr=!0;err=_e3},f:function(){try{if(!normalCompletion&&null!=it["return"])it["return"]()}finally{if(didErr)throw err;}}}}function _unsupportedIterableToArray(o,minLen){if(o){if("string"===typeof o)return _arrayLikeToArray(o,minLen);var n=Object.prototype.toString.call(o).slice(8,-1);"Object"===n&&o.constructor&&(n=o.constructor.name);if("Map"===n||"Set"===n)return Array.from(n);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return _arrayLikeToArray(o,
minLen)}}function _arrayLikeToArray(arr,len){if(null==len||len>arr.length)len=arr.length;for(var i=0,arr2=Array(len);i<len;i++)arr2[i]=arr[i];return arr2}function parseTimeParam(url,pattern){if(url=url.match(pattern)){url=url[1];if(url.match(MATCH_START_STAMP)){pattern=0;for(var array=MATCH_START_STAMP.exec(url);null!==array;){var _array2=array;_array2=Array.isArray(_array2)?_array2:void 0;if(!_array2)if(_array2=void 0,"undefined"!==typeof Symbol&&Symbol.iterator in Object(array)){var _arr=[],_n=
!0,_d=!1,_e=void 0;try{for(var _i=array[Symbol.iterator]();!(_n=(_array2=_i.next()).done)&&(_arr.push(_array2.value),3!==_arr.length);_n=!0);}catch(err){_d=!0,_e=err}finally{try{if(!_n&&null!=_i["return"])_i["return"]()}finally{if(_d)throw _e;}}_array2=_arr}else _array2=void 0;if(!(array=_array2||_unsupportedIterableToArray(array,3)))throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");_array2=
array;array=_array2[1];_array2=_array2[2];"h"===_array2&&(pattern+=3600*parseInt(array,10));"m"===_array2&&(pattern+=60*parseInt(array,10));"s"===_array2&&(pattern+=parseInt(array,10));array=MATCH_START_STAMP.exec(url)}return pattern}if(MATCH_NUMERIC.test(url))return parseInt(url)}}function isObject(val){return null!==val&&"object"===_typeof(val)}function isEqual(a,b){if("function"===typeof a&&"function"===typeof b||(0,_react.isValidElement)(a)&&(0,_react.isValidElement)(b))return!0;if(a instanceof
Array&&b instanceof Array){if(a.length!==b.length)return!1;for(var i=0;i!==a.length;i++)if(!isEqual(a[i],b[i]))return!1;return!0}if(isObject(a)&&isObject(b)){if(Object.keys(a).length!==Object.keys(b).length)return!1;i=0;for(var _Object$keys=Object.keys(a);i<_Object$keys.length;i++){var key=_Object$keys[i];if(!isEqual(a[key],b[key]))return!1}return!0}return a===b}Object.defineProperty(exports,"__esModule",{value:!0});exports.parseStartTime=function(url){return parseTimeParam(url,MATCH_START_QUERY)};
exports.parseEndTime=function(url){return parseTimeParam(url,MATCH_END_QUERY)};exports.randomString=function(){return Math.random().toString(36).substr(2,5)};exports.queryString=function(object){return Object.keys(object).map(function(key){return"".concat(key,"\x3d").concat(object[key])}).join("\x26")};exports.getSDK=function(url,sdkGlobal){var sdkReady=2<arguments.length&&void 0!==arguments[2]?arguments[2]:null,isLoaded=3<arguments.length&&void 0!==arguments[3]?arguments[3]:function(){return!0},
fetchScript=4<arguments.length&&void 0!==arguments[4]?arguments[4]:_loadScript["default"];return window[sdkGlobal]&&isLoaded(window[sdkGlobal])?Promise.resolve(window[sdkGlobal]):new Promise(function(resolve,reject){if(requests[url])requests[url].push({resolve,reject});else{requests[url]=[{resolve,reject}];var onLoaded=function(sdk){requests[url].forEach(function(request){return request.resolve(sdk)})};if(sdkReady){var previousOnReady=window[sdkReady];window[sdkReady]=function(){previousOnReady&&
previousOnReady();onLoaded(window[sdkGlobal])}}fetchScript(url,function(err){err?(requests[url].forEach(function(request){return request.reject(err)}),requests[url]=null):sdkReady||onLoaded(window[sdkGlobal])})}})};exports.getConfig=function(props,defaultProps,showWarning){defaultProps=(0,_deepmerge["default"])(defaultProps.config,props.config);var _iterator=_createForOfIteratorHelper(_props.DEPRECATED_CONFIG_PROPS),_step;try{for(_iterator.s();!(_step=_iterator.n()).done;){var p=_step.value;if(props[p]){var key=
p.replace(/Config$/,""),JSCompiler_temp_const=(0,_deepmerge["default"]),JSCompiler_temp_const$jscomp$0=defaultProps,obj={},key$jscomp$0=key,value=props[p];key$jscomp$0 in obj?Object.defineProperty(obj,key$jscomp$0,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key$jscomp$0]=value;defaultProps=JSCompiler_temp_const(JSCompiler_temp_const$jscomp$0,obj);if(showWarning){var message="ReactPlayer: %c".concat(p," %cis deprecated, please use the config prop instead – ").concat("https://github.com/CookPete/react-player#config-prop");
console.warn(message,"font-weight: bold","")}}}}catch(err){_iterator.e(err)}finally{_iterator.f()}return defaultProps};exports.omit=function(object){for(var _ref,_len=arguments.length,arrays=Array(1<_len?_len-1:0),_key=1;_key<_len;_key++)arrays[_key-1]=arguments[_key];_len=(_ref=[]).concat.apply(_ref,arrays);_ref={};arrays=0;for(_key=Object.keys(object);arrays<_key.length;arrays++){var key=_key[arrays];-1===_len.indexOf(key)&&(_ref[key]=object[key])}return _ref};exports.callPlayer=function(method){if(!this.player||
!this.player[method]){var _this$player="ReactPlayer: ".concat(this.constructor.displayName," player could not call %c").concat(method,"%c – ");this.player?this.player[method]||(_this$player+="The method was not available"):_this$player+="The player was not available";console.warn(_this$player,"font-weight: bold","");return null}for(var _len2=arguments.length,args=Array(1<_len2?_len2-1:0),_key2=1;_key2<_len2;_key2++)args[_key2-1]=arguments[_key2];return(_this$player=this.player)[method].apply(_this$player,
args)};exports.isObject=isObject;exports.isEqual=isEqual;exports.isMediaStream=function(url){return"undefined"!==typeof window&&"undefined"!==typeof window.MediaStream&&url instanceof window.MediaStream};var _react=require("module$node_modules$react$index"),_loadScript=_interopRequireDefault(require("module$node_modules$load_script$index")),_deepmerge=_interopRequireDefault(require("module$node_modules$deepmerge$dist$cjs")),_props=require("module$node_modules$react_player$lib$props"),MATCH_START_QUERY=
/[?&#](?:start|t)=([0-9hms]+)/,MATCH_END_QUERY=/[?&#]end=([0-9hms]+)/,MATCH_START_STAMP=/(\d+)(h|m|s)/g,MATCH_NUMERIC=/^\d+$/,requests={}}
//# sourceMappingURL=module$node_modules$react_player$lib$utils.js.map
